##  Idle Timeout Duration
After a period of inactivity, SAP LeanIX automatically disconnects users for security. The duration can be adjusted using the Idle Timeout Duration setting. Upon disconnection, users are redirected to a login screen where they have the option to log in again.
![Setting Idle Timeout Duration](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275238ac7a441014948cd5d7d5941fec_LowRes.png)
Setting Idle Timeout Duration
**Note**
Setting the duration to 0 Hours and 0 Minutes disables this feature.
